@@ -163,7 +163,7 @@ def test_sparse_methods():
 
 
 def test_pls():
-    pls_als = PLS_ALS(latent_dims=3)
+    pls_als = PLS_ALS(latent_dims=3, random_state=0)
     pls = PLS(latent_dims=3)
     pls_als.fit((X, Y))
     pls.fit((X, Y))
@@ -251,7 +251,7 @@ def test_stochastic_pls():
     spls = PLSStochasticPower(
         latent_dims=3, epochs=250, batch_size=50, learning_rate=1e-1, random_state=1
     ).fit((X, Y))
-    egpls = PLSEigenGame(latent_dims=3, epochs=250, batch_size=50, random_state=1, line_search=True, nesterov=True).fit(
+    egpls = PLSEigenGame(latent_dims=3, epochs=250, batch_size=50, random_state=1, learning_rate=1e-1, nesterov=True).fit(
         (X, Y)
     )
     ghapls = PLSGHAGEP(latent_dims=3, epochs=250, batch_size=50, random_state=1, learning_rate=1e-1, nesterov=True).fit(
@@ -274,7 +274,7 @@ def test_stochastic_cca():
     from cca_zoo.models import CCAGHAGEP, CCAEigenGame
 
     cca = CCA(latent_dims=3).fit((X, Y))
-    egcca = CCAEigenGame(latent_dims=3, epochs=250, batch_size=50, random_state=1).fit((X, Y))
+    egcca = CCAEigenGame(latent_dims=3, epochs=250, batch_size=50, random_state=1, learning_rate=1e-1).fit((X, Y))
     ghacca = CCAGHAGEP(latent_dims=3, epochs=250, batch_size=50, random_state=1, learning_rate=1e-1).fit((X, Y))
     cca_score = cca.score((X, Y))
     egcca_score = egcca.score((X, Y))
