@@ -17,8 +17,8 @@ from cca_zoo.models import (
     ElasticCCA,
     CCA,
     PLS,
-    SCCA_ADMM,
     SCCA_Span,
+    AltMaxVar,
 )
 
 
@@ -58,32 +58,32 @@ data = LinearSimulatedData(
     view_sparsity=[view_1_sparsity, view_2_sparsity],
     correlation=[0.9],
 )
-(X,Y)=data.sample(n)
+(X, Y) = data.sample(n)
 
-tx =data.true_features[0]/np.sqrt(n)
-ty =data.true_features[1]/np.sqrt(n)
+tx = data.true_features[0] / np.sqrt(n)
+ty = data.true_features[1] / np.sqrt(n)
 
-
-# %%
+# %% CCA
 cca = CCA().fit([X, Y])
 plot_model_weights(cca.weights[0], cca.weights[1], tx, ty, title="CCA")
 
-# %%
+# %% PLS
 pls = PLS().fit([X, Y])
 plot_model_weights(pls.weights[0], pls.weights[1], tx, ty, title="PLS")
 
-# %%
-c1 = [0.1, 0.3, 0.7, 0.9]
-c2 = [0.1, 0.3, 0.7, 0.9]
-param_grid = {"c": [c1, c2]}
+# %% PMD
+tau1 = [0.1, 0.3, 0.7, 0.9]
+tau2 = [0.1, 0.3, 0.7, 0.9]
+param_grid = {"tau": [tau1, tau2]}
 pmd = GridSearchCV(SCCA_PMD(), param_grid=param_grid, cv=3, verbose=True).fit([X, Y])
+
 # %%
 plt.figure()
 plt.title("Objective Convergence")
-plt.plot(np.array(pmd.best_estimator_.track[0]["objective"]).T)
+plt.plot(np.array(pmd.best_estimator_.track["objective"][0]))
 plt.ylabel("Objective")
 plt.xlabel("#iterations")
-#%%
+# %%
 plot_model_weights(
     pmd.best_estimator_.weights[0], pmd.best_estimator_.weights[1], tx, ty, title="PMD"
 )
@@ -91,50 +91,57 @@ plot_model_weights(
 # %%
 pd.DataFrame(pmd.cv_results_)
 
-# %%
-scca = SCCA_IPLS(c=[1e-2, 1e-2]).fit([X, Y])
+# %% IPLS
+scca = SCCA_IPLS(tau=[1e-2, 1e-2]).fit([X, Y])
 plot_model_weights(scca.weights[0], scca.weights[1], tx, ty, title="SCCA_IPLS")
 
-# Convergence
 plt.figure()
 plt.title("Objective Convergence")
-plt.plot(np.array(scca.track[0]["objective"]).T)
+plt.plot(np.array(scca.track["objective"][0]))
 plt.ylabel("Objective")
 plt.xlabel("#iterations")
 
-# %%
-scca_pos = SCCA_IPLS(c=[1e-2, 1e-2], positive=[True, True]).fit([X, Y])
+scca_pos = SCCA_IPLS(tau=[1e-2, 1e-2], positive=[True, True]).fit([X, Y])
 plot_model_weights(
     scca_pos.weights[0], scca_pos.weights[1], tx, ty, title="SCCA_IPLS (Positive)"
 )
 
-# Convergence
 plt.figure()
 plt.title("Objective Convergence")
-plt.plot(np.array(scca_pos.track[0]["objective"]).T)
+plt.plot(np.array(scca_pos.track["objective"][0]))
 plt.ylabel("Objective")
 plt.xlabel("#iterations")
 
-# %%
-elasticcca = ElasticCCA(c=[1e-2, 1e-2], l1_ratio=[0.5, 0.5]).fit([X, Y])
+
+elasticcca = ElasticCCA(alpha=[1e-2, 1e-2], l1_ratio=[0.5, 0.5]).fit([X, Y])
 plot_model_weights(
     elasticcca.weights[0], elasticcca.weights[1], tx, ty, title="ELastic CCA"
 )
 
-# Convergence
 plt.figure()
 plt.title("Objective Convergence")
-plt.plot(np.array(elasticcca.track[0]["objective"]).T)
+plt.plot(np.array(elasticcca.track["objective"][0]))
 plt.ylabel("Objective")
 plt.xlabel("#iterations")
 
-# %%
-spancca = SCCA_Span(c=[10, 10], max_iter=2000, rank=20).fit([X, Y])
+
+altmaxvar = AltMaxVar(tau=[1e-5, 1e-5]).fit([X, Y])
+plot_model_weights(
+    altmaxvar.weights[0], altmaxvar.weights[1], tx, ty, title="AltMaxVar"
+)
+
+plt.figure()
+plt.title("Objective Convergence")
+plt.plot(np.array(altmaxvar.track["objective"][0]))
+plt.ylabel("Objective")
+plt.xlabel("#iterations")
+
+
+spancca = SCCA_Span(tau=[10, 10], max_iter=2000, rank=20).fit([X, Y])
 plot_model_weights(spancca.weights[0], spancca.weights[1], tx, ty, title="Span CCA")
 
-# Convergence
 plt.figure()
 plt.title("Objective Convergence")
-plt.plot(np.array(spancca.track[0]["objective"]).T)
+plt.plot(np.array(spancca.track["objective"][0]))
 plt.ylabel("Objective")
 plt.xlabel("#iterations")
